@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 """Manage individual cells in a spreadsheet.
 
@@ -18,7 +18,6 @@ import re
 
 from openpyxl.compat import (
     NUMERIC_TYPES,
-    deprecated,
 )
 
 from openpyxl.utils.exceptions import IllegalCharacterError
@@ -27,6 +26,8 @@ from openpyxl.utils import get_column_letter
 from openpyxl.styles import numbers, is_date_format
 from openpyxl.styles.styleable import StyleableObject
 from openpyxl.worksheet.hyperlink import Hyperlink
+from openpyxl.worksheet.formula import DataTableFormula, ArrayFormula
+from openpyxl.cell.rich_text import CellRichText
 
 # constants
 
@@ -38,7 +39,7 @@ TIME_FORMATS = {
     datetime.timedelta:numbers.FORMAT_DATE_TIMEDELTA,
                 }
 
-STRING_TYPES = (str, bytes)
+STRING_TYPES = (str, bytes, CellRichText)
 KNOWN_TYPES = NUMERIC_TYPES + TIME_TYPES + STRING_TYPES + (bool, type(None))
 
 ILLEGAL_CHARACTERS_RE = re.compile(r'[\000-\010]|[\013-\014]|[\016-\037]')
@@ -68,6 +69,8 @@ def get_type(t, value):
         dt = 's'
     elif isinstance(value, TIME_TYPES):
         dt = 'd'
+    elif isinstance(value, (DataTableFormula, ArrayFormula)):
+        dt = 'f'
     else:
         return
     _TYPES[t] = dt
@@ -159,7 +162,7 @@ class Cell(StyleableObject):
         # truncate if necessary
         value = value[:32767]
         if next(ILLEGAL_CHARACTERS_RE.finditer(value), None):
-            raise IllegalCharacterError
+            raise IllegalCharacterError(f"{value} cannot be used in worksheets.")
         return value
 
     def check_error(self, value):
@@ -190,7 +193,7 @@ class Cell(StyleableObject):
             if not is_date_format(self.number_format):
                 self.number_format = get_time_format(t)
 
-        elif dt == "s":
+        elif dt == "s" and not isinstance(value, CellRichText):
             value = self.check_string(value)
             if len(value) > 1 and value.startswith("="):
                 self.data_type = 'f'
