@@ -1,15 +1,13 @@
-# Copyright (c) 2010-2020 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 from collections import OrderedDict
 
 from openpyxl.descriptors import (
     Bool,
-    String,
     Sequence,
     Alias,
     Convertible,
 )
-from openpyxl.descriptors.excel import ExtensionList
 from openpyxl.descriptors.serialisable import Serialisable
 
 from .rule import Rule
@@ -40,7 +38,7 @@ class ConditionalFormatting(Serialisable):
 
 
     def __hash__(self):
-        return hash(str(self.sqref))
+        return hash(self.sqref)
 
 
     def __repr__(self):
@@ -84,8 +82,6 @@ class ConditionalFormattingList(object):
     def __bool__(self):
         return bool(self._cf_rules)
 
-    __nonzero = __bool__
-
 
     def __len__(self):
         return len(self._cf_rules)
