@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 import re
 
@@ -93,8 +93,9 @@ FORMAT_CURRENCY_EUR_SIMPLE = '[$EUR ]#,##0.00_-'
 
 COLORS = r"\[(BLACK|BLUE|CYAN|GREEN|MAGENTA|RED|WHITE|YELLOW)\]"
 LITERAL_GROUP = r'".*?"' # anything in quotes
-LOCALE_GROUP = r'\[.+\]' # anything in square brackets, including colours
+LOCALE_GROUP = r'\[(?!hh?\]|mm?\]|ss?\])[^\]]*\]' # anything in square brackets, except hours or minutes or seconds
 STRIP_RE = re.compile(f"{LITERAL_GROUP}|{LOCALE_GROUP}")
+TIMEDELTA_RE = re.compile(r'\[hh?\](:mm(:ss(\.0*)?)?)?|\[mm?\](:ss(\.0*)?)?|\[ss?\](\.0*)?', re.I)
 
 
 # Spec 18.8.31 numFmts
@@ -105,7 +106,14 @@ def is_date_format(fmt):
         return False
     fmt = fmt.split(";")[0] # only look at the first format
     fmt = STRIP_RE.sub("", fmt) # ignore some formats
-    return re.search(r"[^\\][dmhysDMHYS]", fmt) is not None
+    return re.search(r"(?<!\\)[dmhysDMHYS]", fmt) is not None
+
+
+def is_timedelta_format(fmt):
+    if fmt is None:
+        return False
+    fmt = fmt.split(";")[0] # only look at the first format
+    return TIMEDELTA_RE.search(fmt) is not None
 
 
 def is_datetime(fmt):
