@@ -1,7 +1,7 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 """
-XML compatability functions
+XML compatibility functions
 """
 
 # Python stdlib imports
@@ -50,6 +50,7 @@ from openpyxl.xml.constants import (
     REL_NS,
     VTYPES_NS,
     COREPROPS_NS,
+    CUSTPROPS_NS,
     DCTERMS_NS,
     DCTERMS_PREFIX,
     XML_NS
@@ -66,6 +67,7 @@ register_namespace('vt', VTYPES_NS)
 register_namespace('xdr', SHEET_DRAWING_NS)
 register_namespace('cdr', CHART_DRAWING_NS)
 register_namespace('xml', XML_NS)
+register_namespace('cust', CUSTPROPS_NS)
 
 
 tostring = partial(tostring, encoding="utf-8")
@@ -80,5 +82,6 @@ def localname(node):
 
 
 def whitespace(node):
-    if node.text != node.text.strip():
+    stripped = node.text.strip()
+    if stripped and node.text != stripped:
         node.set("{%s}space" % XML_NS, "preserve")
